"use client"

import { useState, useEffect } from "react"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Badge } from "@/components/ui/badge"
import { Input } from "@/components/ui/input"
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select"
import { Phone, Shield, CheckCircle, Users, Award, Clock, DollarSign, Star } from "lucide-react"
import { Dialog, DialogContent, DialogHeader, DialogTitle } from "@/components/ui/dialog"
import { RadioGroup, RadioGroupItem } from "@/components/ui/radio-group"
import { Label } from "@/components/ui/label"
import { X, ArrowRight, ArrowLeft } from "lucide-react"

const debtTypes = [
  { id: "all", name: "All Debt Types", description: "Complete debt resolution services" },
  { id: "credit-cards", name: "Credit Card Debt", description: "Settle high-interest credit card balances" },
  { id: "medical", name: "Medical Bills", description: "Resolve overwhelming medical expenses" },
  { id: "personal-loans", name: "Personal Loans", description: "Negotiate personal loan settlements" },
  { id: "business", name: "Business Debt", description: "Commercial debt resolution services" },
  { id: "collections", name: "Collections", description: "Handle debt collection agencies" },
  { id: "tax", name: "Tax Debt", description: "IRS and state tax resolution" },
]

const testimonials = [
  {
    name: "Sarah M.",
    location: "California",
    debt: "$45,000",
    settled: "$18,000",
    savings: "60%",
    quote: "They helped me settle $45,000 in credit card debt for just $18,000. No upfront fees and amazing results!",
  },
  {
    name: "Michael R.",
    location: "Texas",
    debt: "$32,000",
    settled: "$12,800",
    savings: "60%",
    quote: "Professional service and real results. They saved me over $19,000 and got me debt-free in 18 months.",
  },
  {
    name: "Jennifer L.",
    location: "Florida",
    debt: "$28,500",
    settled: "$11,400",
    savings: "60%",
    quote: "Outstanding team! They negotiated my medical bills down significantly. Highly recommend their services.",
  },
]

export default function DebtSettlementLanding() {
  const [selectedDebtType, setSelectedDebtType] = useState("all")
  const [debtAmount, setDebtAmount] = useState("")
  const [phoneNumber, setPhoneNumber] = useState("")
  const [showPopup, setShowPopup] = useState(false)
  const [popupStep, setPopupStep] = useState(1)
  const [popupData, setPopupData] = useState({
    lookingForDebtSettlement: "",
    debtType: "",
    debtAmount: "",
    monthlyIncome: "",
    creditScore: "",
  })

  useEffect(() => {
    const timer = setTimeout(() => {
      setShowPopup(true)
    }, 15000) // Show popup after 10 seconds

    return () => clearTimeout(timer)
  }, [])

  const filteredDebtTypes =
    selectedDebtType === "all"
      ? debtTypes.filter((type) => type.id !== "all")
      : debtTypes.filter((type) => type.id === selectedDebtType)

  const handleCallNow = () => {
    setShowPopup(true)
    setPopupStep(1)
  }

  const handleGetStarted = () => {
    setShowPopup(true)
    setPopupStep(1)
  }

  const handlePopupNext = () => {
    setPopupStep(popupStep + 1)
  }

  const handlePopupBack = () => {
    setPopupStep(popupStep - 1)
  }

  const handlePopupClose = () => {
    setShowPopup(false)
    setPopupStep(1)
    setPopupData({
      lookingForDebtSettlement: "",
      debtType: "",
      debtAmount: "",
      monthlyIncome: "",
      creditScore: "",
    })
  }

  const updatePopupData = (field: string, value: string) => {
    setPopupData((prev) => ({ ...prev, [field]: value }))
  }

  const calculateSavings = () => {
    const debt = Number.parseInt(popupData.debtAmount.replace(/[^0-9]/g, ""))
    if (debt) {
      const savings = Math.round(debt * 0.55) // 55% average savings
      const settlement = debt - savings
      return { savings, settlement, percentage: 55 }
    }
    return { savings: 0, settlement: 0, percentage: 0 }
  }

  const getPersonalizedPhone = () => {
    return "+1 888 810-22-91"
  }

  const handleDirectCall = () => {
    window.open("tel:+18888102291", "_self")
  }

  return (
    <div className="min-h-screen bg-gradient-to-b from-blue-50 to-white">
      {/* Header */}
      <header className="bg-white shadow-sm border-b">
        <div className="container mx-auto px-4 py-4">
          <div className="flex items-center justify-between">
            <div className="flex items-center space-x-2">
              <Shield className="h-8 w-8 text-blue-600" />
              <span className="text-2xl font-bold text-gray-900">DebtFree Solutions</span>
            </div>
            <div className="flex items-center space-x-4">
              <div className="flex items-center space-x-2 text-sm text-gray-600">
                <Award className="h-4 w-4" />
                <span>A+ BBB Rating</span>
              </div>
              <Button
                onClick={handleCallNow}
                className="bg-green-600 hover:bg-green-700 text-white font-semibold px-6 py-2"
              >
                <Phone className="h-4 w-4 mr-2" />
                Get Free Assessment
              </Button>
            </div>
          </div>
        </div>
      </header>

      {/* Hero Section - Enhanced for mobile */}
      <section className="py-12 md:py-16 bg-gradient-to-r from-blue-600 to-blue-800 text-white">
        <div className="container mx-auto px-4">
          <div className="grid lg:grid-cols-2 gap-8 md:gap-12 items-center">
            <div>
              <Badge className="bg-green-500 text-white mb-4 text-sm md:text-base">No Upfront Fees</Badge>
              <h1 className="text-3xl md:text-4xl lg:text-6xl font-bold mb-6 leading-tight">
                Pay Back Less Than What You Owe
              </h1>
              <p className="text-lg md:text-xl mb-8 text-blue-100">
                Our financial experts help you settle your debt for a fraction of what you owe. Performance-based
                results with no upfront fees guaranteed.
              </p>
              <div className="flex flex-col sm:flex-row gap-4 mb-8">
                <Button
                  onClick={handleCallNow}
                  size="lg"
                  className="bg-green-600 hover:bg-green-700 text-white font-semibold px-6 md:px-8 py-3 md:py-4 text-base md:text-lg rounded-xl shadow-lg transform hover:scale-105 transition-all"
                >
                  <Phone className="h-5 w-5 mr-2" />
                  Get Free Consultation
                </Button>
                <Button
                  onClick={handleGetStarted}
                  size="lg"
                  variant="outline"
                  className="border-2 border-white text-white hover:bg-white hover:text-blue-600 px-6 md:px-8 py-3 md:py-4 text-base md:text-lg bg-transparent rounded-xl"
                >
                  Start Assessment
                </Button>
              </div>
              <div className="flex flex-col sm:flex-row sm:items-center sm:space-x-6 space-y-2 sm:space-y-0 text-sm">
                <div className="flex items-center space-x-2">
                  <CheckCircle className="h-5 w-5 text-green-400" />
                  <span>No Upfront Fees</span>
                </div>
                <div className="flex items-center space-x-2">
                  <CheckCircle className="h-5 w-5 text-green-400" />
                  <span>Save 40-60%</span>
                </div>
                <div className="flex items-center space-x-2">
                  <CheckCircle className="h-5 w-5 text-green-400" />
                  <span>Expert Negotiators</span>
                </div>
              </div>
            </div>
            <div className="bg-white rounded-xl p-6 md:p-8 shadow-2xl text-gray-900">
              <h3 className="text-xl md:text-2xl font-bold mb-6 text-center">Get Your Free Debt Analysis</h3>
              <div className="space-y-4">
                <div>
                  <label className="block text-sm font-medium mb-2">Total Debt Amount</label>
                  <Input
                    type="text"
                    placeholder="$25,000"
                    value={debtAmount}
                    onChange={(e) => setDebtAmount(e.target.value)}
                    className="text-base md:text-lg py-3 rounded-lg"
                  />
                </div>
                <div>
                  <label className="block text-sm font-medium mb-2">Debt Type</label>
                  <Input
                    type="text"
                    placeholder="Credit Card"
                    value={phoneNumber}
                    onChange={(e) => setPhoneNumber(e.target.value)}
                    className="text-base md:text-lg py-3 rounded-lg"
                  />
                </div>
                <Button
                  onClick={handleCallNow}
                  className="w-full bg-green-600 hover:bg-green-700 text-white font-semibold py-3 text-base md:text-lg rounded-xl shadow-lg transform hover:scale-105 transition-all"
                >
                  <Phone className="h-5 w-5 mr-2" />
                  Start Free Assessment
                </Button>
                <p className="text-xs text-gray-500 text-center">
                  By clicking above, you consent to receive calls and texts at the number provided. Standard rates may
                  apply.
                </p>
              </div>
            </div>
          </div>
        </div>
      </section>

      {/* Trust Indicators */}
      <section className="py-12 bg-gray-50">
        <div className="container mx-auto px-4">
          <div className="grid grid-cols-2 md:grid-cols-4 gap-8 items-center text-center">
            <div className="flex flex-col items-center">
              <Award className="h-12 w-12 text-blue-600 mb-2" />
              <span className="font-semibold">A+ BBB Rating</span>
            </div>
            <div className="flex flex-col items-center">
              <Users className="h-12 w-12 text-blue-600 mb-2" />
              <span className="font-semibold">50,000+ Clients Helped</span>
            </div>
            <div className="flex flex-col items-center">
              <DollarSign className="h-12 w-12 text-blue-600 mb-2" />
              <span className="font-semibold">$500M+ Debt Settled</span>
            </div>
            <div className="flex flex-col items-center">
              <Shield className="h-12 w-12 text-blue-600 mb-2" />
              <span className="font-semibold">Licensed & Bonded</span>
            </div>
          </div>
        </div>
      </section>

      {/* Debt Type Filter */}
      <section className="py-16">
        <div className="container mx-auto px-4">
          <div className="text-center mb-12">
            <h2 className="text-3xl lg:text-4xl font-bold mb-4">All Major Types of Debt Settlement Available</h2>
            <p className="text-xl text-gray-600 max-w-3xl mx-auto">
              Our expert team handles every type of debt. Select your debt type to see how we can help you save.
            </p>
          </div>

          <div className="max-w-md mx-auto mb-8">
            <Select value={selectedDebtType} onValueChange={setSelectedDebtType}>
              <SelectTrigger className="w-full text-lg py-3">
                <SelectValue placeholder="Select your debt type" />
              </SelectTrigger>
              <SelectContent>
                {debtTypes.map((type) => (
                  <SelectItem key={type.id} value={type.id}>
                    {type.name}
                  </SelectItem>
                ))}
              </SelectContent>
            </Select>
          </div>

          <div className="grid md:grid-cols-2 lg:grid-cols-3 gap-6">
            {filteredDebtTypes.map((type) => (
              <Card key={type.id} className="hover:shadow-lg transition-shadow">
                <CardHeader>
                  <CardTitle className="flex items-center justify-between">
                    {type.name}
                    <CheckCircle className="h-5 w-5 text-green-500" />
                  </CardTitle>
                  <CardDescription>{type.description}</CardDescription>
                </CardHeader>
                <CardContent>
                  <div className="space-y-2 mb-4">
                    <div className="flex justify-between">
                      <span>Typical Savings:</span>
                      <span className="font-semibold text-green-600">40-60%</span>
                    </div>
                    <div className="flex justify-between">
                      <span>Upfront Fees:</span>
                      <span className="font-semibold text-green-600">$0</span>
                    </div>
                    <div className="flex justify-between">
                      <span>Success Rate:</span>
                      <span className="font-semibold text-blue-600">95%+</span>
                    </div>
                  </div>
                  <Button onClick={handleCallNow} className="w-full bg-blue-600 hover:bg-blue-700">
                    <Phone className="h-4 w-4 mr-2" />
                    Get Free Assessment
                  </Button>
                </CardContent>
              </Card>
            ))}
          </div>
        </div>
      </section>

      {/* How It Works */}
      <section className="py-16 bg-gray-50">
        <div className="container mx-auto px-4">
          <div className="text-center mb-12">
            <h2 className="text-3xl lg:text-4xl font-bold mb-4">How Our Debt Settlement Process Works</h2>
            <p className="text-xl text-gray-600">Simple, transparent, and effective debt resolution</p>
          </div>

          <div className="grid md:grid-cols-3 gap-8">
            <div className="text-center">
              <div className="bg-blue-600 text-white rounded-full w-16 h-16 flex items-center justify-center mx-auto mb-4 text-2xl font-bold">
                1
              </div>
              <h3 className="text-xl font-semibold mb-3">Free Consultation</h3>
              <p className="text-gray-600">
                Call us for a free, no-obligation consultation. We'll analyze your debt and create a personalized
                settlement strategy.
              </p>
            </div>
            <div className="text-center">
              <div className="bg-blue-600 text-white rounded-full w-16 h-16 flex items-center justify-center mx-auto mb-4 text-2xl font-bold">
                2
              </div>
              <h3 className="text-xl font-semibold mb-3">Expert Negotiation</h3>
              <p className="text-gray-600">
                Our trained professionals negotiate with your creditors to reduce your debt by 40-60% or more.
              </p>
            </div>
            <div className="text-center">
              <div className="bg-blue-600 text-white rounded-full w-16 h-16 flex items-center justify-center mx-auto mb-4 text-2xl font-bold">
                3
              </div>
              <h3 className="text-xl font-semibold mb-3">Debt Freedom</h3>
              <p className="text-gray-600">
                Pay only when we successfully settle your debt. No upfront fees, just results-based performance.
              </p>
            </div>
          </div>
        </div>
      </section>

      {/* Benefits Section */}
      <section className="py-16">
        <div className="container mx-auto px-4">
          <div className="grid lg:grid-cols-2 gap-12 items-center">
            <div>
              <h2 className="text-3xl lg:text-4xl font-bold mb-6">Why Choose Our Debt Settlement Services?</h2>
              <div className="space-y-6">
                <div className="flex items-start space-x-4">
                  <CheckCircle className="h-6 w-6 text-green-500 mt-1 flex-shrink-0" />
                  <div>
                    <h3 className="font-semibold text-lg">No Upfront Fees</h3>
                    <p className="text-gray-600">
                      We only get paid when we successfully settle your debt. No hidden costs or upfront charges.
                    </p>
                  </div>
                </div>
                <div className="flex items-start space-x-4">
                  <CheckCircle className="h-6 w-6 text-green-500 mt-1 flex-shrink-0" />
                  <div>
                    <h3 className="font-semibold text-lg">Financial Experts</h3>
                    <p className="text-gray-600">
                      Founded and managed by financial experts who understand the debt resolution industry inside and
                      out.
                    </p>
                  </div>
                </div>
                <div className="flex items-start space-x-4">
                  <CheckCircle className="h-6 w-6 text-green-500 mt-1 flex-shrink-0" />
                  <div>
                    <h3 className="font-semibold text-lg">Performance-Based Results</h3>
                    <p className="text-gray-600">
                      Our team has a relentless commitment to deliver measurable, performance-based results to every
                      client.
                    </p>
                  </div>
                </div>
                <div className="flex items-start space-x-4">
                  <CheckCircle className="h-6 w-6 text-green-500 mt-1 flex-shrink-0" />
                  <div>
                    <h3 className="font-semibold text-lg">Quality Service Driven</h3>
                    <p className="text-gray-600">
                      Well-trained staff meeting the strictest client service regulations with trusted affiliate
                      network.
                    </p>
                  </div>
                </div>
              </div>
            </div>
            <div className="bg-blue-600 text-white rounded-lg p-8">
              <h3 className="text-2xl font-bold mb-6">Typical Client Results</h3>
              <div className="space-y-4">
                <div className="flex justify-between items-center">
                  <span>Average Debt Reduction:</span>
                  <span className="text-2xl font-bold text-green-300">55%</span>
                </div>
                <div className="flex justify-between items-center">
                  <span>Average Settlement Time:</span>
                  <span className="text-2xl font-bold text-green-300">18 months</span>
                </div>
                <div className="flex justify-between items-center">
                  <span>Client Satisfaction Rate:</span>
                  <span className="text-2xl font-bold text-green-300">98%</span>
                </div>
              </div>
              <Button
                onClick={handleCallNow}
                className="w-full mt-6 bg-green-600 hover:bg-green-700 text-white font-semibold py-3"
              >
                <Phone className="h-5 w-5 mr-2" />
                Start Your Assessment Today
              </Button>
            </div>
          </div>
        </div>
      </section>

      {/* Testimonials */}
      <section className="py-16 bg-gray-50">
        <div className="container mx-auto px-4">
          <div className="text-center mb-12">
            <h2 className="text-3xl lg:text-4xl font-bold mb-4">Real Results from Real Clients</h2>
            <p className="text-xl text-gray-600">See how we've helped thousands achieve debt freedom</p>
          </div>

          <div className="grid md:grid-cols-3 gap-8">
            {testimonials.map((testimonial, index) => (
              <Card key={index} className="bg-white">
                <CardHeader>
                  <div className="flex items-center justify-between mb-2">
                    <div>
                      <CardTitle className="text-lg">{testimonial.name}</CardTitle>
                      <CardDescription>{testimonial.location}</CardDescription>
                    </div>
                    <div className="flex">
                      {[...Array(5)].map((_, i) => (
                        <Star key={i} className="h-4 w-4 fill-yellow-400 text-yellow-400" />
                      ))}
                    </div>
                  </div>
                  <div className="bg-green-50 p-3 rounded-lg">
                    <div className="text-sm text-gray-600">
                      Original Debt: <span className="font-semibold">{testimonial.debt}</span>
                    </div>
                    <div className="text-sm text-gray-600">
                      Settled For: <span className="font-semibold text-green-600">{testimonial.settled}</span>
                    </div>
                    <div className="text-lg font-bold text-green-600">Saved {testimonial.savings}!</div>
                  </div>
                </CardHeader>
                <CardContent>
                  <p className="text-gray-600 italic">"{testimonial.quote}"</p>
                </CardContent>
              </Card>
            ))}
          </div>
        </div>
      </section>

      {/* Final CTA */}
      <section id="contact-form" className="py-16 bg-gradient-to-r from-green-600 to-green-800 text-white">
        <div className="container mx-auto px-4 text-center">
          <h2 className="text-3xl lg:text-5xl font-bold mb-6">Ready to Become Debt-Free?</h2>
          <p className="text-xl mb-8 max-w-3xl mx-auto">
            Don't let debt control your life any longer. Call now for your free consultation and start your journey to
            financial freedom today.
          </p>

          <div className="flex flex-col sm:flex-row gap-4 justify-center items-center mb-8">
            <Button
              onClick={handleCallNow}
              size="lg"
              className="bg-white text-green-600 hover:bg-gray-100 font-bold px-12 py-4 text-xl"
            >
              <Phone className="h-6 w-6 mr-3" />
              Start Free Assessment Now
            </Button>
            <div className="text-lg">
              <Clock className="h-5 w-5 inline mr-2" />
              Available 24/7 - Free Consultation
            </div>
          </div>

          <div className="grid grid-cols-1 md:grid-cols-3 gap-6 max-w-4xl mx-auto text-center">
            <div className="bg-white/10 rounded-lg p-6">
              <Shield className="h-12 w-12 mx-auto mb-3" />
              <h3 className="font-semibold mb-2">100% Confidential</h3>
              <p className="text-sm">Your information is completely secure and private</p>
            </div>
            <div className="bg-white/10 rounded-lg p-6">
              <DollarSign className="h-12 w-12 mx-auto mb-3" />
              <h3 className="font-semibold mb-2">No Upfront Costs</h3>
              <p className="text-sm">We only get paid when we settle your debt</p>
            </div>
            <div className="bg-white/10 rounded-lg p-6">
              <CheckCircle className="h-12 w-12 mx-auto mb-3" />
              <h3 className="font-semibold mb-2">Proven Results</h3>
              <p className="text-sm">95%+ success rate with average 55% savings</p>
            </div>
          </div>
        </div>
      </section>

      {/* Footer */}
      <footer className="bg-gray-900 text-white py-12">
        <div className="container mx-auto px-4">
          <div className="grid md:grid-cols-4 gap-8">
            <div>
              <div className="flex items-center space-x-2 mb-4">
                <Shield className="h-8 w-8 text-blue-400" />
                <span className="text-xl font-bold">DebtFree Solutions</span>
              </div>
              <p className="text-gray-400 mb-4">
                Professional debt settlement services with no upfront fees. Get the financial freedom you deserve.
              </p>
              <Button onClick={handleCallNow} className="bg-green-600 hover:bg-green-700">
                <Phone className="h-4 w-4 mr-2" />
                Get Free Assessment
              </Button>
            </div>
            <div>
              <h3 className="font-semibold mb-4">Services</h3>
              <ul className="space-y-2 text-gray-400">
                <li>Credit Card Debt Settlement</li>
                <li>Medical Bill Negotiation</li>
                <li>Personal Loan Settlement</li>
                <li>Business Debt Resolution</li>
                <li>Tax Debt Relief</li>
              </ul>
            </div>
            <div>
              <h3 className="font-semibold mb-4">Company</h3>
              <ul className="space-y-2 text-gray-400">
                <li>About Us</li>
                <li>How It Works</li>
                <li>Success Stories</li>
                <li>FAQ</li>
                <li>Contact</li>
              </ul>
            </div>
            <div>
              <h3 className="font-semibold mb-4">Legal</h3>
              <ul className="space-y-2 text-gray-400">
                <li>Privacy Policy</li>
                <li>Terms of Service</li>
                <li>Licensing</li>
                <li>Disclosures</li>
              </ul>
            </div>
          </div>
          <div className="border-t border-gray-800 mt-8 pt-8 text-center text-gray-400">
            <p>&copy; 2024 DebtFree Solutions. All rights reserved. Licensed and bonded debt settlement company.</p>
          </div>
        </div>
      </footer>

      {/* Popup Funnel */}
      <Dialog open={showPopup} onOpenChange={setShowPopup}>
        <DialogContent className="sm:max-w-lg max-w-[95vw] max-h-[90vh] overflow-y-auto bg-gradient-to-br from-white to-blue-50 border-2 border-blue-200 shadow-2xl">
          <DialogHeader className="relative">
            <div className="absolute -top-2 -right-2 bg-gradient-to-r from-red-500 to-red-600 text-white text-xs px-2 py-1 rounded-full animate-pulse">
              LIMITED TIME
            </div>
            <DialogTitle className="flex items-center justify-between text-2xl font-bold bg-gradient-to-r from-blue-600 to-purple-600 bg-clip-text text-transparent">
              <span>💰 Quick Debt Assessment</span>
              <Button
                variant="ghost"
                size="sm"
                onClick={handlePopupClose}
                className="h-8 w-8 p-0 hover:bg-red-100 rounded-full"
              >
                <X className="h-5 w-5 text-gray-500 hover:text-red-600" />
              </Button>
            </DialogTitle>
            <div className="w-full bg-gray-200 rounded-full h-2 mt-4">
              <div
                className="bg-gradient-to-r from-blue-500 to-green-500 h-2 rounded-full transition-all duration-500 ease-out"
                style={{ width: `${(popupStep / 6) * 100}%` }}
              ></div>
            </div>
            <p className="text-sm text-gray-600 mt-2">Step {popupStep} of 6</p>
          </DialogHeader>

          {/* Step 1: Initial Question */}
          {popupStep === 1 && (
            <div className="space-y-6 p-2">
              <div className="text-center bg-gradient-to-r from-blue-500 to-purple-600 text-white rounded-xl p-6 shadow-lg">
                <div className="text-4xl mb-3">🎯</div>
                <h3 className="text-2xl font-bold mb-2">Are you looking for debt settlement help?</h3>
                <p className="text-blue-100 text-lg">We can help you reduce your debt by up to 60%</p>
              </div>
              <RadioGroup
                value={popupData.lookingForDebtSettlement}
                onValueChange={(value) => updatePopupData("lookingForDebtSettlement", value)}
                className="space-y-4"
              >
                <div className="flex items-center space-x-3 p-4 rounded-lg border-2 border-gray-200 hover:border-green-400 hover:bg-green-50 transition-all cursor-pointer">
                  <RadioGroupItem value="yes" id="yes" className="text-green-600" />
                  <Label htmlFor="yes" className="cursor-pointer text-lg font-medium flex-1">
                    ✅ Yes, I need help with my debt
                  </Label>
                </div>
                <div className="flex items-center space-x-3 p-4 rounded-lg border-2 border-gray-200 hover:border-gray-400 hover:bg-gray-50 transition-all cursor-pointer">
                  <RadioGroupItem value="no" id="no" />
                  <Label htmlFor="no" className="cursor-pointer text-lg font-medium flex-1">
                    ❌ No, just browsing
                  </Label>
                </div>
              </RadioGroup>
              <div className="flex gap-3">
                <Button
                  onClick={handlePopupClose}
                  variant="outline"
                  className="flex-1 bg-transparent border-2 hover:bg-gray-50 py-3 text-lg"
                  disabled={popupData.lookingForDebtSettlement === "no"}
                >
                  {popupData.lookingForDebtSettlement === "no" ? "Thanks for visiting!" : "Maybe Later"}
                </Button>
                <Button
                  onClick={handlePopupNext}
                  className="flex-1 bg-gradient-to-r from-blue-600 to-blue-700 hover:from-blue-700 hover:to-blue-800 text-white py-3 text-lg shadow-lg transform hover:scale-105 transition-all"
                  disabled={!popupData.lookingForDebtSettlement || popupData.lookingForDebtSettlement === "no"}
                >
                  Continue <ArrowRight className="h-5 w-5 ml-2" />
                </Button>
              </div>
            </div>
          )}

          {/* Step 2: Debt Type */}
          {popupStep === 2 && (
            <div className="space-y-6 p-2">
              <div className="text-center bg-gradient-to-r from-green-500 to-teal-600 text-white rounded-xl p-6 shadow-lg">
                <div className="text-4xl mb-3">💳</div>
                <h3 className="text-2xl font-bold mb-2">What type of debt do you have?</h3>
                <p className="text-green-100 text-lg">Select your primary debt concern</p>
              </div>
              <RadioGroup
                value={popupData.debtType}
                onValueChange={(value) => updatePopupData("debtType", value)}
                className="space-y-3"
              >
                <div className="flex items-center space-x-3 p-4 rounded-lg border-2 border-gray-200 hover:border-blue-400 hover:bg-blue-50 transition-all cursor-pointer">
                  <RadioGroupItem value="credit-cards" id="credit-cards" />
                  <Label htmlFor="credit-cards" className="cursor-pointer text-lg font-medium flex-1">
                    💳 Credit Card Debt
                  </Label>
                </div>
                <div className="flex items-center space-x-3 p-4 rounded-lg border-2 border-gray-200 hover:border-blue-400 hover:bg-blue-50 transition-all cursor-pointer">
                  <RadioGroupItem value="medical" id="medical" />
                  <Label htmlFor="medical" className="cursor-pointer text-lg font-medium flex-1">
                    🏥 Medical Bills
                  </Label>
                </div>
                <div className="flex items-center space-x-3 p-4 rounded-lg border-2 border-gray-200 hover:border-blue-400 hover:bg-blue-50 transition-all cursor-pointer">
                  <RadioGroupItem value="personal-loans" id="personal-loans" />
                  <Label htmlFor="personal-loans" className="cursor-pointer text-lg font-medium flex-1">
                    💰 Personal Loans
                  </Label>
                </div>
                <div className="flex items-center space-x-3 p-4 rounded-lg border-2 border-gray-200 hover:border-blue-400 hover:bg-blue-50 transition-all cursor-pointer">
                  <RadioGroupItem value="business" id="business" />
                  <Label htmlFor="business" className="cursor-pointer text-lg font-medium flex-1">
                    🏢 Business Debt
                  </Label>
                </div>
                <div className="flex items-center space-x-3 p-4 rounded-lg border-2 border-gray-200 hover:border-blue-400 hover:bg-blue-50 transition-all cursor-pointer">
                  <RadioGroupItem value="multiple" id="multiple" />
                  <Label htmlFor="multiple" className="cursor-pointer text-lg font-medium flex-1">
                    📊 Multiple Types
                  </Label>
                </div>
              </RadioGroup>
              <div className="flex gap-3">
                <Button
                  onClick={handlePopupBack}
                  variant="outline"
                  className="flex-1 bg-transparent border-2 hover:bg-gray-50 py-3 text-lg"
                >
                  <ArrowLeft className="h-5 w-5 mr-2" /> Back
                </Button>
                <Button
                  onClick={handlePopupNext}
                  className="flex-1 bg-gradient-to-r from-blue-600 to-blue-700 hover:from-blue-700 hover:to-blue-800 text-white py-3 text-lg shadow-lg transform hover:scale-105 transition-all"
                  disabled={!popupData.debtType}
                >
                  Continue <ArrowRight className="h-5 w-5 ml-2" />
                </Button>
              </div>
            </div>
          )}

          {/* Step 3: Debt Amount */}
          {popupStep === 3 && (
            <div className="space-y-6 p-2">
              <div className="text-center bg-gradient-to-r from-red-500 to-pink-600 text-white rounded-xl p-6 shadow-lg">
                <div className="text-4xl mb-3">💸</div>
                <h3 className="text-2xl font-bold mb-2">How much total debt do you have?</h3>
                <p className="text-red-100 text-lg">Include all unsecured debts</p>
              </div>
              <RadioGroup
                value={popupData.debtAmount}
                onValueChange={(value) => updatePopupData("debtAmount", value)}
                className="space-y-3"
              >
                <div className="flex items-center space-x-3 p-4 rounded-lg border-2 border-gray-200 hover:border-red-400 hover:bg-red-50 transition-all cursor-pointer">
                  <RadioGroupItem value="$10,000-$25,000" id="10k-25k" />
                  <Label htmlFor="10k-25k" className="cursor-pointer text-lg font-medium flex-1">
                    💵 $10,000 - $25,000
                  </Label>
                </div>
                <div className="flex items-center space-x-3 p-4 rounded-lg border-2 border-gray-200 hover:border-red-400 hover:bg-red-50 transition-all cursor-pointer">
                  <RadioGroupItem value="$25,000-$50,000" id="25k-50k" />
                  <Label htmlFor="25k-50k" className="cursor-pointer text-lg font-medium flex-1">
                    💰 $25,000 - $50,000
                  </Label>
                </div>
                <div className="flex items-center space-x-3 p-4 rounded-lg border-2 border-gray-200 hover:border-red-400 hover:bg-red-50 transition-all cursor-pointer">
                  <RadioGroupItem value="$50,000-$100,000" id="50k-100k" />
                  <Label htmlFor="50k-100k" className="cursor-pointer text-lg font-medium flex-1">
                    💎 $50,000 - $100,000
                  </Label>
                </div>
                <div className="flex items-center space-x-3 p-4 rounded-lg border-2 border-gray-200 hover:border-red-400 hover:bg-red-50 transition-all cursor-pointer">
                  <RadioGroupItem value="$100,000+" id="100k-plus" />
                  <Label htmlFor="100k-plus" className="cursor-pointer text-lg font-medium flex-1">
                    🏆 $100,000+
                  </Label>
                </div>
              </RadioGroup>
              <div className="flex gap-3">
                <Button
                  onClick={handlePopupBack}
                  variant="outline"
                  className="flex-1 bg-transparent border-2 hover:bg-gray-50 py-3 text-lg"
                >
                  <ArrowLeft className="h-5 w-5 mr-2" /> Back
                </Button>
                <Button
                  onClick={handlePopupNext}
                  className="flex-1 bg-gradient-to-r from-blue-600 to-blue-700 hover:from-blue-700 hover:to-blue-800 text-white py-3 text-lg shadow-lg transform hover:scale-105 transition-all"
                  disabled={!popupData.debtAmount}
                >
                  Continue <ArrowRight className="h-5 w-5 ml-2" />
                </Button>
              </div>
            </div>
          )}

          {/* Step 4: Monthly Income */}
          {popupStep === 4 && (
            <div className="space-y-6 p-2">
              <div className="text-center bg-gradient-to-r from-purple-500 to-indigo-600 text-white rounded-xl p-6 shadow-lg">
                <div className="text-4xl mb-3">📈</div>
                <h3 className="text-2xl font-bold mb-2">What's your monthly income?</h3>
                <p className="text-purple-100 text-lg">This helps us determine the best settlement strategy</p>
              </div>
              <RadioGroup
                value={popupData.monthlyIncome}
                onValueChange={(value) => updatePopupData("monthlyIncome", value)}
                className="space-y-3"
              >
                <div className="flex items-center space-x-3 p-4 rounded-lg border-2 border-gray-200 hover:border-purple-400 hover:bg-purple-50 transition-all cursor-pointer">
                  <RadioGroupItem value="Under $3,000" id="under-3k" />
                  <Label htmlFor="under-3k" className="cursor-pointer text-lg font-medium flex-1">
                    📊 Under $3,000
                  </Label>
                </div>
                <div className="flex items-center space-x-3 p-4 rounded-lg border-2 border-gray-200 hover:border-purple-400 hover:bg-purple-50 transition-all cursor-pointer">
                  <RadioGroupItem value="$3,000-$5,000" id="3k-5k" />
                  <Label htmlFor="3k-5k" className="cursor-pointer text-lg font-medium flex-1">
                    📈 $3,000 - $5,000
                  </Label>
                </div>
                <div className="flex items-center space-x-3 p-4 rounded-lg border-2 border-gray-200 hover:border-purple-400 hover:bg-purple-50 transition-all cursor-pointer">
                  <RadioGroupItem value="$5,000-$8,000" id="5k-8k" />
                  <Label htmlFor="5k-8k" className="cursor-pointer text-lg font-medium flex-1">
                    💹 $5,000 - $8,000
                  </Label>
                </div>
                <div className="flex items-center space-x-3 p-4 rounded-lg border-2 border-gray-200 hover:border-purple-400 hover:bg-purple-50 transition-all cursor-pointer">
                  <RadioGroupItem value="$8,000+" id="8k-plus" />
                  <Label htmlFor="8k-plus" className="cursor-pointer text-lg font-medium flex-1">
                    🚀 $8,000+
                  </Label>
                </div>
              </RadioGroup>
              <div className="flex gap-3">
                <Button
                  onClick={handlePopupBack}
                  variant="outline"
                  className="flex-1 bg-transparent border-2 hover:bg-gray-50 py-3 text-lg"
                >
                  <ArrowLeft className="h-5 w-5 mr-2" /> Back
                </Button>
                <Button
                  onClick={handlePopupNext}
                  className="flex-1 bg-gradient-to-r from-blue-600 to-blue-700 hover:from-blue-700 hover:to-blue-800 text-white py-3 text-lg shadow-lg transform hover:scale-105 transition-all"
                  disabled={!popupData.monthlyIncome}
                >
                  Continue <ArrowRight className="h-5 w-5 ml-2" />
                </Button>
              </div>
            </div>
          )}

          {/* Step 5: Credit Score */}
          {popupStep === 5 && (
            <div className="space-y-6 p-2">
              <div className="text-center bg-gradient-to-r from-orange-500 to-red-600 text-white rounded-xl p-6 shadow-lg">
                <div className="text-4xl mb-3">📊</div>
                <h3 className="text-2xl font-bold mb-2">What's your approximate credit score?</h3>
                <p className="text-orange-100 text-lg">Don't worry - we help people with all credit scores</p>
              </div>
              <RadioGroup
                value={popupData.creditScore}
                onValueChange={(value) => updatePopupData("creditScore", value)}
                className="space-y-3"
              >
                <div className="flex items-center space-x-3 p-4 rounded-lg border-2 border-gray-200 hover:border-orange-400 hover:bg-orange-50 transition-all cursor-pointer">
                  <RadioGroupItem value="Poor (300-579)" id="poor" />
                  <Label htmlFor="poor" className="cursor-pointer text-lg font-medium flex-1">
                    📉 Poor (300-579)
                  </Label>
                </div>
                <div className="flex items-center space-x-3 p-4 rounded-lg border-2 border-gray-200 hover:border-orange-400 hover:bg-orange-50 transition-all cursor-pointer">
                  <RadioGroupItem value="Fair (580-669)" id="fair" />
                  <Label htmlFor="fair" className="cursor-pointer text-lg font-medium flex-1">
                    📊 Fair (580-669)
                  </Label>
                </div>
                <div className="flex items-center space-x-3 p-4 rounded-lg border-2 border-gray-200 hover:border-orange-400 hover:bg-orange-50 transition-all cursor-pointer">
                  <RadioGroupItem value="Good (670-739)" id="good" />
                  <Label htmlFor="good" className="cursor-pointer text-lg font-medium flex-1">
                    📈 Good (670-739)
                  </Label>
                </div>
                <div className="flex items-center space-x-3 p-4 rounded-lg border-2 border-gray-200 hover:border-orange-400 hover:bg-orange-50 transition-all cursor-pointer">
                  <RadioGroupItem value="Excellent (740+)" id="excellent" />
                  <Label htmlFor="excellent" className="cursor-pointer text-lg font-medium flex-1">
                    🌟 Excellent (740+)
                  </Label>
                </div>
                <div className="flex items-center space-x-3 p-4 rounded-lg border-2 border-gray-200 hover:border-orange-400 hover:bg-orange-50 transition-all cursor-pointer">
                  <RadioGroupItem value="Not sure" id="not-sure" />
                  <Label htmlFor="not-sure" className="cursor-pointer text-lg font-medium flex-1">
                    ❓ Not sure
                  </Label>
                </div>
              </RadioGroup>
              <div className="flex gap-3">
                <Button
                  onClick={handlePopupBack}
                  variant="outline"
                  className="flex-1 bg-transparent border-2 hover:bg-gray-50 py-3 text-lg"
                >
                  <ArrowLeft className="h-5 w-5 mr-2" /> Back
                </Button>
                <Button
                  onClick={handlePopupNext}
                  className="flex-1 bg-gradient-to-r from-green-600 to-green-700 hover:from-green-700 hover:to-green-800 text-white py-3 text-lg shadow-lg transform hover:scale-105 transition-all"
                  disabled={!popupData.creditScore}
                >
                  Get My Offer <ArrowRight className="h-5 w-5 ml-2" />
                </Button>
              </div>
            </div>
          )}

          {/* Step 6: Advanced Final Offer */}
          {popupStep === 6 && (
            <div className="space-y-4 p-2">
              <div className="text-center">
                <div className="bg-gradient-to-r from-green-500 to-green-600 text-white rounded-xl p-6 mb-4 shadow-xl animate-pulse">
                  <div className="flex items-center justify-center mb-3">
                    <CheckCircle className="h-10 w-10 mr-3" />
                    <h3 className="text-2xl md:text-3xl font-bold">🎉 CONGRATULATIONS!</h3>
                  </div>
                  <p className="text-lg md:text-xl">You qualify for IMMEDIATE debt relief!</p>
                </div>
              </div>

              {/* Personalized Savings Display */}
              <div className="bg-gradient-to-br from-blue-50 to-indigo-100 border-2 border-blue-300 rounded-xl p-4 md:p-6 shadow-lg">
                <h4 className="font-bold text-xl md:text-2xl mb-4 text-center text-blue-800">
                  Your Personalized Debt Settlement Analysis:
                </h4>
                <div className="grid grid-cols-2 gap-4 mb-4">
                  <div className="text-center bg-white rounded-lg p-3 shadow-md">
                    <div className="text-sm text-gray-600">Current Debt</div>
                    <div className="text-xl md:text-2xl font-bold text-red-600">{popupData.debtAmount}</div>
                  </div>
                  <div className="text-center bg-white rounded-lg p-3 shadow-md">
                    <div className="text-sm text-gray-600">After Settlement</div>
                    <div className="text-xl md:text-2xl font-bold text-green-600">
                      ${calculateSavings().settlement.toLocaleString()}
                    </div>
                  </div>
                </div>
                <div className="text-center bg-gradient-to-r from-green-400 to-green-500 text-white rounded-xl p-4 shadow-lg">
                  <div className="text-sm">YOU COULD SAVE</div>
                  <div className="text-3xl md:text-4xl font-bold">${calculateSavings().savings.toLocaleString()}</div>
                  <div className="text-lg font-semibold">
                    That's {calculateSavings().percentage}% OFF your total debt!
                  </div>
                </div>
              </div>

              {/* Urgency Timer */}
              <div className="bg-gradient-to-r from-red-500 to-red-600 text-white rounded-xl p-4 shadow-lg animate-bounce">
                <div className="flex items-center justify-center mb-2">
                  <Clock className="h-6 w-6 mr-2" />
                  <h4 className="font-bold text-lg">⚡ LIMITED TIME OFFER ⚡</h4>
                </div>
                <p className="text-center font-semibold">This pre-qualified offer expires in 15 minutes!</p>
                <p className="text-center text-sm mt-1">Call now to lock in your savings before rates change</p>
              </div>

              {/* Social Proof */}
              <div className="bg-gradient-to-r from-yellow-400 to-orange-500 text-white rounded-xl p-4 shadow-lg">
                <div className="flex items-center justify-center mb-2">
                  <Users className="h-6 w-6 mr-2" />
                  <span className="font-bold">🔥 HIGH DEMAND ALERT</span>
                </div>
                <p className="text-center text-sm">
                  <strong>127 people</strong> called in the last hour • <strong>Only 3 specialists</strong> available
                  now
                </p>
              </div>

              {/* Main Call to Action */}
              <div className="text-center">
                <p className="text-lg font-bold mb-3">Call Your Dedicated Debt Specialist NOW:</p>
                <div className="bg-gradient-to-r from-green-600 to-green-700 text-white rounded-xl p-4 md:p-6 mb-4 shadow-xl">
                  <div className="text-3xl md:text-4xl font-bold mb-2">📞 +1 888 810-22-91</div>
                  <div className="text-base md:text-lg mb-2">Available Mon - Fri - Call Within 15 Minutes</div>
                  <div className="text-sm bg-white/20 rounded-lg p-2">
                    Mention Your Credit for instant qualification
                  </div>
                </div>

                <Button
                  onClick={handleDirectCall}
                  className="w-full bg-gradient-to-r from-green-600 to-green-700 hover:from-green-700 hover:to-green-800 text-white font-bold py-4 md:py-6 text-lg md:text-xl mb-4 shadow-xl transform hover:scale-105 transition-all rounded-xl"
                >
                  <Phone className="h-6 w-6 mr-3" />📞 CALL NOW - FREE CONSULTATION
                </Button>

                <Button
                  onClick={handleDirectCall}
                  variant="outline"
                  className="w-full border-2 border-green-600 text-green-600 hover:bg-green-50 font-semibold py-3 mb-4 bg-transparent rounded-xl"
                >
                  <Phone className="h-5 w-5 mr-2" />
                  Tap to Call on Mobile
                </Button>
              </div>

              {/* Benefits Reminder */}
              <div className="grid grid-cols-3 gap-2 text-center text-sm">
                <div className="bg-white border-2 border-blue-200 rounded-xl p-3 shadow-md hover:shadow-lg transition-all">
                  <Shield className="h-6 w-6 mx-auto mb-1 text-blue-600" />
                  <div className="font-semibold">100% Free</div>
                  <div className="text-gray-600">No Upfront Costs</div>
                </div>
                <div className="bg-white border-2 border-green-200 rounded-xl p-3 shadow-md hover:shadow-lg transition-all">
                  <CheckCircle className="h-6 w-6 mx-auto mb-1 text-green-600" />
                  <div className="font-semibold">Guaranteed</div>
                  <div className="text-gray-600">Results or No Fee</div>
                </div>
                <div className="bg-white border-2 border-purple-200 rounded-xl p-3 shadow-md hover:shadow-lg transition-all">
                  <Clock className="h-6 w-6 mx-auto mb-1 text-purple-600" />
                  <div className="font-semibold">Fast Setup</div>
                  <div className="text-gray-600">Start Today</div>
                </div>
              </div>

              {/* Final Urgency Push */}
              <div className="text-center bg-gradient-to-r from-red-500 to-red-600 text-white rounded-xl p-4 shadow-lg">
                <p className="font-bold text-lg mb-1">⏰ DON'T WAIT - DEBT GROWS DAILY!</p>
                <p className="text-sm">Every day you wait costs you more money in interest and fees</p>
              </div>

              {/* Trust Indicators */}
              <div className="text-center">
                <div className="flex justify-center items-center space-x-4 mb-3">
                  <div className="flex">
                    {[...Array(5)].map((_, i) => (
                      <Star key={i} className="h-4 w-4 fill-yellow-400 text-yellow-400" />
                    ))}
                  </div>
                  <span className="text-sm font-semibold">4.9/5 Rating</span>
                  <span className="text-sm text-gray-600">• A+ BBB Rating</span>
                </div>
                <p className="text-xs text-gray-500 mb-2">Licensed & Bonded • Your call is 100% confidential</p>
                <Button
                  onClick={handlePopupClose}
                  variant="ghost"
                  className="text-gray-400 hover:text-gray-600 text-xs"
                >
                  I'll think about it (and keep paying high interest)
                </Button>
              </div>
            </div>
          )}
        </DialogContent>
      </Dialog>
    </div>
  )
}
